%define module	fido2

Name:		python-%{module}
Version:	1.2.0
Release:	%mkrel 2
Summary:	Library for FIDO 2.0, including communication with a device over USB
Group:		Development/Python
License:	BSD-like, ASL 2.0, MPLv2.0
URL:		https://github.com/Yubico/python-fido2
Source0:	https://github.com/Yubico/python-fido2/releases/download/%{version}/fido2-%{version}.tar.gz
Patch0:  	0001-relax-req-on-cryptography.patch
BuildArch:	noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:	python3dist(setuptools)
BuildRequires:  python3dist(poetry-core)

%description
Provides library functionality for communicating with a FIDO device over USB as
well as verifying attestation and assertion signatures.

This library aims to support the FIDO U2F and FIDO 2.0 protocols for
communicating with a USB authenticator via the Client-to-Authenticator Protocol
(CTAP 1 and 2). In addition to this low-level device access, classes defined in
the `fido2.client` and `fido2.server` modules implement higher level operations
which are useful when interfacing with an Authenticator, or when implementing
WebAuthn support for a Relying Party.

%package -n python3-%{module}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
Provides library functionality for communicating with a FIDO device over USB as
well as verifying attestation and assertion signatures.

This library aims to support the FIDO U2F and FIDO 2.0 protocols for
communicating with a USB authenticator via the Client-to-Authenticator Protocol
(CTAP 1 and 2). In addition to this low-level device access, classes defined in
the `fido2.client` and `fido2.server` modules implement higher level operations
which are useful when interfacing with an Authenticator, or when implementing
WebAuthn support for a Relying Party.

%prep
%autosetup -p1 -n %{module}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files fido2

%files -n python3-%{module} -f %{pyproject_files}

%doc NEWS README.adoc
%license COPYING COPYING.APLv2 COPYING.MPLv2


%changelog
* Mon Mar 03 2025 daviddavid <daviddavid> 1.2.0-2.mga10
+ Revision: 2159261
- rebuild for python 3.13

* Sat Nov 30 2024 danf <danf> 1.2.0-1.mga10
+ Revision: 2120167
- Update to ver. 1.2.0

* Thu May 09 2024 danf <danf> 1.1.3-1.mga10
+ Revision: 2063120
- Update to ver. 1.1.3

* Thu Jan 25 2024 danf <danf> 1.1.2-4.mga10
+ Revision: 2034230
- Switch to %%autosetup so the requirements patch takes effect

* Fri Jan 05 2024 papoteur <papoteur> 1.1.2-3.mga10
+ Revision: 2027833
- relax requirements

* Thu Jan 04 2024 papoteur <papoteur> 1.1.2-2.mga10
+ Revision: 2027615
- rebuild for python 3.12

* Wed Sep 06 2023 danf <danf> 1.1.2-1.mga10
+ Revision: 1984576
- Update to ver. 1.1.2

* Wed Nov 16 2022 danf <danf> 1.1.0-1.mga9
+ Revision: 1907843
- Update to ver. 1.1.0

* Sat Sep 10 2022 neoclust <neoclust> 1.0.0-1.mga9
+ Revision: 1886587
- New version 	1.0.0

* Wed Mar 23 2022 umeabot <umeabot> 0.9.3-2.mga9
+ Revision: 1822732
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 danf <danf> 0.9.3-1.mga9
+ Revision: 1775047
- Update to ver. 0.9.3

* Sat Aug 28 2021 wally <wally> 0.9.1-1.mga9
+ Revision: 1743257
- new version 0.9.1

* Sun Apr 18 2021 daviddavid <daviddavid> 0.8.1-2.mga9
+ Revision: 1716793
- rebuild for python 3.9

* Sat Mar 14 2020 danf <danf> 0.8.1-1.mga8
+ Revision: 1556169
- imported package python-fido2

